@@ -9,12 +9,12 @@ from decimal import Decimal
 class BasePlugin(type):
     def __init__(cls, name, bases, attrs):
         super(BasePlugin, cls).__init__(name)
-        if not hasattr(cls, 'plugins'):
+        if not hasattr(cls, "plugins"):
             cls.plugins = []
         else:
             cls.register(cls)  # Called when a plugin class is imported
 
-    def register(cls, plugin):
+    def register(cls, plugin=None):
         cls.plugins.append(plugin())
 
 
@@ -46,28 +46,35 @@ class Plugin(object, metaclass=BasePlugin):
 
     def get_weather(self):
         try:
-            if 'weather' not in self.cache:
-                self.logger.debug('[cache miss] Fetching weather data')
+            if "weather" not in self.cache:
+                self.logger.debug("[cache miss] Fetching weather data")
                 url = "https://{endpoint}/data/2.5/weather?lon={lon}&lat={lat}&units={units}&APPID={api_key}".format(
-                    endpoint=self.config.get('openweathermap', 'endpoint', fallback='api.openweathermap.org'),
-                    lat=self.config.get('openweathermap', 'lat'),
-                    lon=self.config.get('openweathermap', 'lon'),
-                    units=self.config.get(
-                        'openweathermap', 'units', fallback='metric'),
-                    api_key=self.config.get('openweathermap', 'api_key'),
+                    endpoint=self.config.get(
+                        "openweathermap", "endpoint", fallback="api.openweathermap.org"
+                    ),
+                    lat=self.config.get("openweathermap", "lat"),
+                    lon=self.config.get("openweathermap", "lon"),
+                    units=self.config.get("openweathermap", "units", fallback="metric"),
+                    api_key=self.config.get("openweathermap", "api_key"),
                 )
 
                 res = requests.get(url)
 
                 res.raise_for_status()
 
-                self.cache['weather'] = res.json()
+                self.cache["weather"] = res.json()
 
-            return self.cache['weather']
+            return self.cache["weather"]
 
         except requests.exceptions.HTTPError as e:
-            hybridlogger.ha_log(self.logger, self.hass_api, "ERROR", 'Unable to get weather data. [{0}]: {1}'.format(
-                                type(e).__name__, str(e)))
+            hybridlogger.ha_log(
+                self.logger,
+                self.hass_api,
+                "ERROR",
+                "Unable to get weather data. [{0}]: {1}".format(
+                    type(e).__name__, str(e)
+                ),
+            )
             raise e
 
     def process(self, **args):
