@@ -10,6 +10,18 @@ import uuid
 from omnik.plugin_output import Plugin
 import threading
 
+MEASUREMENT_CLASSES = [
+    "power",
+    "current",
+    "temperature",
+    "voltage",
+    "frequency",
+    "flow",
+]
+MEASUREMENT_TOTAL_INCREASING_CLASSES = ["energy", "gas", "operation_time", "count"]
+STATE_CLASS_MEASUREMENT = "measurement"
+STATE_CLASS_TOTAL_INCREASING = "total_increasing"
+
 
 class mqtt(Plugin):
     def __init__(self):
@@ -61,14 +73,6 @@ class mqtt(Plugin):
             self.discovery_prefix = self.config.get("output.mqtt", "discovery_prefix")
         else:
             self.discovery_prefix = "homeassistant"
-        # The mqtt name of the inverter device
-        # use the configured device name or the device name from the omnik portal
-        # if self.config.has_option('output.mqtt', 'device_name'):
-        #    self.device_name = self.config.get('output.mqtt', 'device_name')
-        # else:
-        #    self.device_name = None
-        # self.config.mqtt_fields['<field_name>']['name'] can have an override
-        # self.mqtt_field_name_override_init = {}
         # Init topics dict
         self.topics = {}
         # Init config dict
@@ -96,24 +100,11 @@ class mqtt(Plugin):
     def _init_config(self, msg):
         # Check if init is needed
         asset_classes = set()
-        last_reset = {}
         for field in msg:
             if field in self.config.data_field_config:
                 asset_class = self.config.data_field_config[field]["asset"]
                 if asset_class not in asset_classes:
                     asset_classes.add(asset_class)
-                    # set last_reset payload per assset_class
-                    if asset_class == "dsmr":
-                        pl = self.config.get(f"dsmr.{msg['terminal']}", "start_date")
-                    elif asset_class == "dsmr_gas":
-                        pl = self.config.get(
-                            f"dsmr.{msg['terminal']}", "start_date_gas"
-                        )
-                    else:
-                        pl = self.config.get(f"plant.{msg['plant_id']}", "start_date")
-                    last_reset[asset_class] = (
-                        pl if type(pl) is datetime else datetime.fromtimestamp(0)
-                    )
 
         # Init from using mqtt field config (loaded from json)
         # self.config.data_field_config
@@ -129,7 +120,7 @@ class mqtt(Plugin):
 
         # Flag init as done
         # self.mqtt_field_name_override_init[msg['plant_id']] = True
-        return (asset_classes, last_reset)
+        return asset_classes
 
     def _mqtt_on_connect(self, client, userdata, flags, rc=0, properties=None):
         if rc == 0:
@@ -154,15 +145,11 @@ class mqtt(Plugin):
             topics[asset_class]["state"] = f"{topics[asset_class]['main']}/state"
             topics[asset_class]["attr"] = f"{topics[asset_class]['main']}/attr"
             topics[asset_class]["config"] = {}
-            topics[asset_class]["lrst"] = {}
             for field in self.config.data_field_config:
                 if field in msg:
                     topics[asset_class]["config"][
                         field
                     ] = f"{topics[asset_class]['main']}/{field}/config"
-                    topics[asset_class]["lrst"][
-                        field
-                    ] = f"{topics[asset_class]['main']}/{field}/lrst"
         return topics
 
     def _device_payload(self, msg, asset_classes):
@@ -220,18 +207,29 @@ class mqtt(Plugin):
                 "uniq_id": f"{msg[identifier]}_{field}",
                 "name": f"{fieldname}",
                 "stat_t": "~/state",
-                "stat_cla": "measurement",
                 "json_attr_t": "~/attr",
                 "val_tpl": f"{{{{(value_json.{field}{self.config.data_field_config[field]['filter']})}}}}",
                 "dev": device_pl[asset_class],
             }
-            # Set device class and last_reset_topic if configured
+
+            # Set device and state class if configured
             if self.config.data_field_config[field]["dev_cla"]:
                 config_pl[field]["dev_cla"] = self.config.data_field_config[field][
                     "dev_cla"
                 ]
-            if self.config.data_field_config[field]["dev_cla"] == "energy":
-                config_pl[field]["lrst_t"] = f"~/{field}/lrst"
+            if (
+                self.config.data_field_config[field]["dev_cla"]
+                in MEASUREMENT_TOTAL_INCREASING_CLASSES
+            ):
+                state_class = STATE_CLASS_TOTAL_INCREASING
+            elif self.config.data_field_config[field]["dev_cla"] in MEASUREMENT_CLASSES:
+                state_class = STATE_CLASS_MEASUREMENT
+            else:
+                state_class = None
+
+            # set the state class for measurements
+            if state_class:
+                config_pl[field]["stat_cla"] = state_class
             # Set icon if configured
             if self.config.data_field_config[field]["ic"]:
                 config_pl[field][
@@ -278,23 +276,6 @@ class mqtt(Plugin):
                 attr_pl_class[attr] = self._encode_attribute(msg, attr)
         return attr_pl_class
 
-    def _last_reset_payload(self, msg, last_reset):
-        last_reset_pl = {}
-        # Generate MQTT config topics
-        for field in self.config.data_field_config:
-            # field: name, dev_cla, ic, unit, filter
-            # Only generate payload for available data
-            if self.config.data_field_config[field]["dev_cla"] != "energy":
-                # skip publication
-                continue
-            asset_class = self.config.data_field_config[field]["asset"]
-            if not asset_class or asset_class not in last_reset:
-                # skip publication
-                continue
-            if field in msg:
-                last_reset_pl[field] = last_reset[asset_class]
-        return last_reset_pl
-
     def _encode_attribute(self, msg, attr):
         if attr not in msg:
             return None
@@ -428,57 +409,6 @@ class mqtt(Plugin):
                     f"Unhandled error publishing states: {e}",
                 )
 
-    def _publish_last_reset(self, topics, last_reset_pl):
-        """Publish last_reset timestamps for energy sensors."""
-        for field in last_reset_pl:
-            try:
-                payload = str(last_reset_pl[field].isoformat())
-                last_reset = self.config.data_field_config[field]["tags"].get(
-                    "last_reset"
-                )
-                if last_reset == "today":
-                    payload = str(
-                        datetime.now(self.timezone)
-                        .replace(
-                            hour=0,
-                            minute=0,
-                            second=0,
-                            microsecond=0,
-                        )
-                        .isoformat()
-                    )
-                elif type(last_reset) is datetime:
-                    payload = str(last_reset.isoformat())
-                asset_class = self.config.data_field_config[field].get("asset")
-                # publish last_reset timestamp
-                if self.mqtt_client.publish(
-                    topics[asset_class]["lrst"][field],
-                    payload,
-                    retain=self.mqtt_retain,
-                ):
-                    hybridlogger.ha_log(
-                        self.logger,
-                        self.hass_api,
-                        "DEBUG",
-                        f"Publishing last_reset {payload} to "
-                        f"{topics[asset_class]['lrst'][field]} successful.",
-                    )
-                else:
-                    hybridlogger.ha_log(
-                        self.logger,
-                        self.hass_api,
-                        "WARNING",
-                        f"Publishing last_reset {payload} to "
-                        f"{topics[asset_class]['lrst'][field]} failed!",
-                    )
-            except Exception as e:
-                hybridlogger.ha_log(
-                    self.logger,
-                    self.hass_api,
-                    "ERROR",
-                    f"Unhandled error publishing last_reset: {e}",
-                )
-
     def process(self, **args):
         """
         Send data to over mqtt (compliant with Home Assistant MQTT discovery standard
@@ -497,7 +427,7 @@ class mqtt(Plugin):
         msg = args["msg"]
 
         # Assemble config
-        asset_classes, last_reset = self._init_config(msg)
+        asset_classes = self._init_config(msg)
 
         # Publish config
         self._publish_config(msg)
@@ -505,10 +435,6 @@ class mqtt(Plugin):
         # publish attributes
         self._publish_attributes(msg, asset_classes)
 
-        # publish last reset
-        last_reset_pl = self._last_reset_payload(msg, last_reset)
-        self._publish_last_reset(self.topics[msg["plant_id"]], last_reset_pl)
-
         # publish state
         value_pl = self._value_payload(msg)
         self._publish_state(self.topics[msg["plant_id"]], value_pl, asset_classes)
